- .Object
The object to initialize.
- type
A character string defining the type of transaction as defined by valid_types.
- category
A character string, custom category for this transaction.
- name
A character string, custom name or ID for this transaction.
- amount
Numeric, the amount of money loaned.
- period
Integer, number of months to fully repay the loan.
- interest
Numeric, the nominal interest rate per annum (a value between 0 and 1).
- first_month
Character string in YYYY.MM format,
defining the initial date of the loan.
- schedule
One of the following, defining the repayment schedule:
"annuity": Equal rates of total repayment over period,
thereby interest is relatively higher
and principal payment relatively lower at the beginning.
"amortization": Repayment of equal rates of principal payment with decreasing interest and total payments over period.
"maturity": Repayment of the full loan amount at the end of period,
until then only payment of interest.
- due_month
Integer value defining the first month of principal repayment. The selected schedule will not begin before this month,
until then only interest rates are due.
Beware that this is a different behaviour of this argument compared to transaction.
- valid_types
A character string,
the model types defined by set_types to be used for validation.
If "default", pre-defined example types are used.
- value
A valid data frame to be used as the value slot directly,
omitting calculation via amount, period, interest, etc.