You can use this method to add or replace transactions to an existing object of class
operations.
update_operations(obj, cut_to_period = TRUE, warning = FALSE, as_transaction) <- value# S4 method for operations
update_operations(obj, cut_to_period = TRUE, warning = FALSE,
as_transaction) <- value
An updated object of class operations.
An object of class operations.
Logical,
whether to adjust the data of value to the period covered by obj. This means that missing months
will be added with zero values,
and months that lie beyond the covered period will be dropped.
This only affects objects of class revenue and expense.
Logical,
if TRUE shows a warning when cut_to_period=TRUE and months are adjusted.
Optional list of vectors of arguments for value of class loan or
depreciation,
as used by as_transaction.
If given,
the object provided as value will also be processed as if as_transaction was also called. This is repeated
for each vector of arguments.
An object of either class revenue,
expense,
loan,
depreciation, or
transaction_plan.